Firebird Pack for PowerConsole — Firebird Pack for PowerConsole v0.9.1 documentation

### Navigation

- index
- next |
- Firebird Pack for PowerConsole v0.9.1 documentation »

# Firebird Pack for PowerConsole

Firebird Pack for PowerConsole is extensive package that enables PowerConsole to work with Firebird databases. Beside special database-related commands allows execution of arbitrary SQL statements. It also installs various objects to user namespace for direct database manipulations in python code.

# Contents

- SQL Support
  - Supported SQL statements
  - Using Python expressions in SQL
- Additional PowerConsole Commands
  - CONNECT
  - DISCONNECT
  - READY
  - SHOW commands
  - SET commands
  - SET TERM
- Command line options
- Python Objects
  - Using database objects in PowerConsole
  - Available objects

# Indices and tables

- Index
- Module Index
- Search Page

### Navigation

- index
- next |
- Firebird Pack for PowerConsole v0.9.1 documentation »